from django.apps import AppConfig
from celery.schedules import crontab


class AllianceAuthConfig(AppConfig):
    name = 'allianceauth'

    def ready(self) -> None:
        import allianceauth.checks # noqa
        from django_celery_beat.models import CrontabSchedule, PeriodicTask
        from allianceauth.framework.cron import offset_cron

        PeriodicTask.objects.update_or_create(
            name='esi_cleanup_callbackredirect',
            defaults={
                'task': 'esi.tasks.cleanup_callbackredirect',
                'crontab': CrontabSchedule.objects.get_or_create(minute='0', hour='0', day_of_week='*', day_of_month='*', month_of_year='*', timezone='UTC')[0],
            },
        )
        PeriodicTask.objects.update_or_create(
            name='esi_cleanup_token',
            defaults={
                'task': 'esi.tasks.cleanup_token',
                'crontab': CrontabSchedule.objects.get_or_create(minute='0', hour='0', day_of_week='*', day_of_month='*', month_of_year='*', timezone='UTC')[0],
            },
        )

        z = CrontabSchedule.from_schedule(offset_cron(crontab(minute='0', hour='*/6')))
        PeriodicTask.objects.update_or_create(
            name='run_model_update',
            defaults={
                'task': 'allianceauth.eveonline.tasks.run_model_update',
                'crontab': CrontabSchedule.objects.get_or_create(  # Convert the offsetted cron into a DB object
                    minute=z.minute, hour=z.hour, day_of_week=z.day_of_week, day_of_month=z.day_of_month, month_of_year=z.month_of_year, timezone=z.timezone)[0],
            },
        )

        z = CrontabSchedule.from_schedule(offset_cron(crontab(minute='0', hour='*/4')))
        PeriodicTask.objects.update_or_create(
            name='check_all_character_ownership',
            defaults={
                'task': 'allianceauth.authentication.tasks.check_all_character_ownership',
                'crontab': CrontabSchedule.objects.get_or_create(  # Convert the offsetted cron into a DB object
                    minute=z.minute, hour=z.hour, day_of_week=z.day_of_week, day_of_month=z.day_of_month, month_of_year=z.month_of_year, timezone=z.timezone)[0],
            },
        )
        PeriodicTask.objects.update_or_create(
            name='analytics_daily_stats',
            defaults={
                'task': 'allianceauth.analytics.tasks.analytics_daily_stats',
                'crontab': CrontabSchedule.objects.get_or_create(
                    minute='0', hour='12', day_of_week='*', day_of_month='*', month_of_year='*', timezone='UTC')[0],
            },
        )
